Operators
=========

.. automodule:: pyquest_cffi.ops
    :members:
    :undoc-members:
    :show-inheritance:

Unitary
-------

.. automodule:: pyquest_cffi.ops.ops
    :members:
    :undoc-members:
    :show-inheritance:

Errors
------

.. automodule:: pyquest_cffi.ops.errors
    :members:
    :undoc-members:
    :show-inheritance:
